@@ -245,33 +245,31 @@ def stats(
                 sample_names = [sample_names]
 
             if cellranger:
+                mode_ = "cellranger"
                 s3paths_ = [
                     os.path.join(s3paths[0], sn, "CR-results", "")
                     for sn in sample_names
                 ]
-                data = get_stats(s3paths_, sample_ids, mode="cellranger")
             elif hash_tags:
+                mode_ = "hashtags"
                 s3paths_ = [
                     os.path.join(s3paths[0], sn, "Hashtag_results", "")
                     for sn in sample_names
                 ]
-                data = get_stats(s3paths_, sample_ids, mode="hashtags")
             else:
-                # assuming `path` is `seqc-results` full path
-                # append `output-prefix` to path appending `_mini_summary.json`
-                if isinstance(results_folder, str):
-                    s3paths_ = [
-                        os.path.join(s3paths[0], sn, results_folder)
-                        for sn in sample_names
-                    ]
-                elif results_folder is None:
-                    s3paths_ = [os.path.join(s3paths[0], sn) for sn in sample_names]
-                else:
-                    s3paths_ = [
-                        os.path.join(s3paths[0], sn, rf)
-                        for sn, rf in zip(sample_names, results_folder)
-                    ]
-                data = get_stats(s3paths_, sample_ids)
+                mode_ = "seqc"
+                s3paths_ = [os.path.join(s3paths[0], sn, "") for sn in sample_names]
+
+            if isinstance(results_folder, str):
+                results_folder = [results_folder] * len(sample_names)
+
+            if isinstance(results_folder, list):
+                s3paths_ = [
+                    os.path.join(s3paths[0], sn, rf, "")
+                    for sn, rf in zip(sample_names, results_folder)
+                ]
+
+            data = get_stats(s3paths_, sample_ids, mode=mode_)
 
             if data:
                 contents = data
@@ -479,14 +477,18 @@ def upload_stats_main(
         else:
             try:
                 from tabulate import tabulate
-            except ImportError:
-                os.system("pip3 install tabulate")
-                from tabulate import tabulate
-            print(
-                tabulate(
-                    data_frame, headers="keys", tablefmt="fancy_grid", showindex=False
+
+                print(
+                    tabulate(
+                        data_frame,
+                        headers="keys",
+                        tablefmt="fancy_grid",
+                        showindex=False,
+                    )
                 )
-            )
+            except ImportError:
+                print("INFO: Consider installing tabulate\n\tpip install tabulate")
+                print(data_frame.to_numpy())
 
     if missed_samplesids:
         print(
